==> tine20-allinone_2020.03.4.tar.bz2: Filemanager/js/Filemanager-lang-en-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0 - Filemanager\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Password for download required"
: "Password for download required"

, "Submit"
: "Submit"

, "File not found!"
: "File not found!"

, "Name"
: "Name"

, "Size"
: "Size"

, "Last Modified"
: "Last Modified"

, "Description"
: "Description"

, "Folder, Folders"
: [
  "Folder"
 ,"Folders"

]
, "File, Files"
: [
  "File"
 ,"Files"

]
, "Default behavior when double-clicking on a Row"
: "Default behavior when double-clicking on a Row"

, "Defines which action should be executed by default when double-clicked."
: "Defines which action should be executed by default when double-clicked."

, "Invalid Filename"
: "Invalid Filename"

, "Content type"
: "Content type"

, "path"
: "path"

, "URL"
: "URL"

, "Password"
: "Password"

, "Valid until"
: "Valid until"

, "Send as e-mail"
: "Send as e-mail"

, "Download"
: "Download"

, "Create Public Link"
: "Create Public Link"

, "Remove record"
: "Remove record"

, "Creating new Download Link..."
: "Creating new Download Link..."

, "Deleting Download Links..."
: "Deleting Download Links..."

, "Deleting Download Link..."
: "Deleting Download Link..."

, "Created By"
: "Created By"

, "Creation Time"
: "Creation Time"

, "Expiration Time"
: "Expiration Time"

, "Access Count"
: "Access Count"

, "Last Modified Time"
: "Last Modified Time"

, "Last Modified By"
: "Last Modified By"

, "Revision"
: "Revision"

, "This folder has own revision settings"
: "This folder has own revision settings"

, "Revision active"
: "Revision active"

, "Limit revision amount to"
: "Limit revision amount to"

, "Hold-back in months"
: "Hold-back in months"

, "Upload Failed"
: "Upload Failed"

, "It is not permitted to store files in this folder!"
: "It is not permitted to store files in this folder!"

, "Select a file"
: "Select a file"

, "Select files"
: "Select files"

, "Select a folder"
: "Select a folder"

, "Select folders"
: "Select folders"

, "Select an item"
: "Select an item"

, "Select items"
: "Select items"

, "Checking ..."
: "Checking ..."

, "Overwrite Existing File?"
: "Overwrite Existing File?"

, "Do you really want to overwrite the selected file?"
: "Do you really want to overwrite the selected file?"

, "Tags"
: "Tags"

, "Revision Size"
: "Revision Size"

, "Total size of all available revisions"
: "Total size of all available revisions"

, "Indexed"
: "Indexed"

, "File contents is part of the search index"
: "File contents is part of the search index"

, "Upload"
: "Upload"

, "Open Data Safe"
: "Open Data Safe"

, "Folder Up"
: "Folder Up"

, "Close Data Safe"
: "Close Data Safe"

, "Filemanager"
: "Filemanager"

, "Save locally"
: "Save locally"

, "Close"
: "Close"

, "Loading preview ..."
: "Loading preview ..."

, "Edit folder"
: "Edit folder"

, "edit file"
: "edit file"

, "Public Links"
: "Public Links"

, "Type"
: "Type"

, "Not yet indexed"
: "Not yet indexed"

, "Modified By"
: "Modified By"

, "Enter description"
: "Enter description"

, "Service Unavailable"
: "Service Unavailable"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."

, "File(s) already exists"
: "File(s) already exists"

, "Do you want to replace the following file(s)?"
: "Do you want to replace the following file(s)?"

, "An error occurred creating this folder"
: "An error occurred creating this folder"

, "Item with this name already exists!"
: "Item with this name already exists!"

, "Whole Filemanager"
: "Whole Filemanager"

, "This Folder"
: "This Folder"

, "Search"
: "Search"

, "The grant to download files"
: "The grant to download files"

, "Publish"
: "Publish"

, "The grant to create anonymous download links for files"
: "The grant to create anonymous download links for files"

, "Copying data .. {0}"
: "Copying data .. {0}"

, "Moving data .. {0}"
: "Moving data .. {0}"

, "Please wait"
: "Please wait"

, "Error while uploading \"{fileName}\". Please try again later."
: "Error while uploading \"{fileName}\". Please try again later."

, "Quick Search"
: "Quick Search"

, "Content Type"
: "Content Type"

, "File Contents"
: "File Contents"

, "Download Link, Download Links"
: [
  "Download Link"
 ,"Download Links"

]
, "Node Download Links"
: "Node Download Links"

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: "Sorry, Tine 2.0 would have liked to show you the contents of the file."

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: "This is possible for .doc, .jpg, .pdf and even more file formats."

, "Interested? Then let us know!"
: "Interested? Then let us know!"

, "We would be happy to make you a non-binding offer."
: "We would be happy to make you a non-binding offer."

, "No preview available yet - Please try again in a few minutes."
: "No preview available yet - Please try again in a few minutes."

, "Notifications"
: "Notifications"

, "This folder has own notification settings"
: "This folder has own notification settings"

, "Notification"
: "Notification"

, "Notification active"
: "Notification active"

, "Summary"
: "Summary"

, "Once a Day, Every {0} Days"
: [
  "Once a Day"
 ,"Every {0} Days"

]
, "No"
: "No"

, "Don't summarize"
: "Don't summarize"

, "Once a day"
: "Once a day"

, "Every 3 days"
: "Every 3 days"

, "Once a week"
: "Once a week"

, "Once a month"
: "Once a month"

, "Once a year"
: "Once a year"

, "Search for users ..."
: "Search for users ..."

, "No permission"
: "No permission"

, "all"
: "all"

, "Search for groups ..."
: "Search for groups ..."

, "Grants"
: "Grants"

, "This folder has its own grants"
: "This folder has its own grants"

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: "Grants of a folder also apply recursively to all sub folders unless they have their own grants."

, "This folder is part of the data safe"
: "This folder is part of the data safe"

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."

, "Usage"
: "Usage"

, "This folder has own quota"
: "This folder has own quota"

, "Quota"
: "Quota"

, "No quota set (examples: 10 GB, 900 MB)"
: "No quota set (examples: 10 GB, 900 MB)"

, "Current Usage"
: "Current Usage"

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."

, "File Type"
: "File Type"

, "Usage by File Type"
: "Usage by File Type"

, "User"
: "User"

, "Usage by User"
: "Usage by User"

, "unknown"
: "unknown"

, "Reload"
: "Reload"

, "Create Folder"
: "Create Folder"

, "New Folder"
: "New Folder"

, "Please enter the name of the new folder:"
: "Please enter the name of the new folder:"

, "No {0} added"
: "No {0} added"

, "You have to supply a {0} name!"
: "You have to supply a {0} name!"

, "Edit Properties"
: "Edit Properties"

, "Rename"
: "Rename"

, "Rename {0}"
: "Rename {0}"

, "Please enter the new name of the {0}:"
: "Please enter the new name of the {0}:"

, "Not renamed {0}"
: "Not renamed {0}"

, "System Link"
: "System Link"

, "Use this link to share the entry with other system users"
: "Use this link to share the entry with other system users"

, "Delete"
: "Delete"

, "Do you really want to delete the following files?"
: "Do you really want to delete the following files?"

, "Move"
: "Move"

, "Move Items"
: "Move Items"

, "Preview"
: "Preview"

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."

, "Folder has been published successfully"
: "Folder has been published successfully"

, "File has been published successfully"
: "File has been published successfully"

, "Public Download URL"
: "Public Download URL"

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."

, "you can't remove your own admin grant"
: "you can't remove your own admin grant"

, "My folders"
: "My folders"

, "Shared folders"
: "Shared folders"

, "Other users folders"
: "Other users folders"

, "Received"
: "Received"

, "To"
: "To"

, "Cc"
: "Cc"

, "Bcc"
: "Bcc"

, "From (E-Mail)"
: "From (E-Mail)"

, "From (Name)"
: "From (Name)"

, "Body"
: "Body"

, "Attachments"
: "Attachments"

, "Destination is a Subfolder"
: "Destination is a Subfolder"

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."

, "Destination has the same Path"
: "Destination has the same Path"

, "The destination has the same path as the source. No action has been performed."
: "The destination has the same path as the source. No action has been performed."

, "manage shared folders"
: "manage shared folders"

, "Create new shared folders"
: "Create new shared folders"

, "Manage anonymous download links"
: "Manage anonymous download links"

, "Allow viewing, adding and deleting download links"
: "Allow viewing, adding and deleting download links"

, "Folder"
: "Folder"

, "File"
: "File"

, "Download Link"
: "Download Link"

, "Once a Day"
: "Once a Day"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Filemanager/js/Filemanager-lang-en-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0 - Filemanager\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Usage"
: "Usage"

, "Size"
: "Size"

, "This folder has own quota"
: "This folder has own quota"

, "Quota"
: "Quota"

, "No quota set (examples: 10 GB, 900 MB)"
: "No quota set (examples: 10 GB, 900 MB)"

, "Current Usage"
: "Current Usage"

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."

, "Revision Size"
: "Revision Size"

, "File Type"
: "File Type"

, "Usage by File Type"
: "Usage by File Type"

, "User"
: "User"

, "Usage by User"
: "Usage by User"

, "unknown"
: "unknown"

, "Service Unavailable"
: "Service Unavailable"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."

, "File(s) already exists"
: "File(s) already exists"

, "Do you want to replace the following file(s)?"
: "Do you want to replace the following file(s)?"

, "An error occurred creating this folder"
: "An error occurred creating this folder"

, "Item with this name already exists!"
: "Item with this name already exists!"

, "Filemanager"
: "Filemanager"

, "Save locally"
: "Save locally"

, "Close"
: "Close"

, "Loading preview ..."
: "Loading preview ..."

, "Node Download Links"
: "Node Download Links"

, "Create Public Link"
: "Create Public Link"

, "Remove record"
: "Remove record"

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."

, "Creating new Download Link..."
: "Creating new Download Link..."

, "Deleting Download Links..."
: "Deleting Download Links..."

, "Deleting Download Link..."
: "Deleting Download Link..."

, "URL"
: "URL"

, "Created By"
: "Created By"

, "Creation Time"
: "Creation Time"

, "Expiration Time"
: "Expiration Time"

, "Password"
: "Password"

, "Access Count"
: "Access Count"

, "Last Modified Time"
: "Last Modified Time"

, "Last Modified By"
: "Last Modified By"

, "Folder, Folders"
: [
  "Folder"
 ,"Folders"

]
, "Total size of all available revisions"
: "Total size of all available revisions"

, "File contents is part of the search index"
: "File contents is part of the search index"

, "Upload"
: "Upload"

, "Open Data Safe"
: "Open Data Safe"

, "Folder Up"
: "Folder Up"

, "Locking data safe..."
: "Locking data safe..."

, "Unlocking data safe..."
: "Unlocking data safe..."

, "Close Data Safe"
: "Close Data Safe"

, "Upload Failed"
: "Upload Failed"

, "Upload File"
: "Upload File"

, "It is not permitted to store files in this folder!"
: "It is not permitted to store files in this folder!"

, "Whole Filemanager"
: "Whole Filemanager"

, "This Folder"
: "This Folder"

, "Search"
: "Search"

, "path"
: "path"

, "Reload"
: "Reload"

, "Create Folder"
: "Create Folder"

, "New Folder"
: "New Folder"

, "Please enter the name of the new folder:"
: "Please enter the name of the new folder:"

, "No {0} added"
: "No {0} added"

, "You have to supply a {0} name!"
: "You have to supply a {0} name!"

, "Edit Properties"
: "Edit Properties"

, "Rename"
: "Rename"

, "Rename {0}"
: "Rename {0}"

, "Please enter the new name of the {0}:"
: "Please enter the new name of the {0}:"

, "Not renamed {0}"
: "Not renamed {0}"

, "System Link"
: "System Link"

, "Use this link to share the entry with other system users"
: "Use this link to share the entry with other system users"

, "Delete"
: "Delete"

, "Do you really want to delete the following files?"
: "Do you really want to delete the following files?"

, "Move"
: "Move"

, "Move Items"
: "Move Items"

, "Preview"
: "Preview"

, "Publish"
: "Publish"

, "Folder has been published successfully"
: "Folder has been published successfully"

, "File has been published successfully"
: "File has been published successfully"

, "Notification"
: "Notification"

, "Notification active"
: "Notification active"

, "Summary"
: "Summary"

, "Once a Day, Every {0} Days"
: [
  "Once a Day"
 ,"Every {0} Days"

]
, "No"
: "No"

, "Don't summarize"
: "Don't summarize"

, "Once a day"
: "Once a day"

, "Every 3 days"
: "Every 3 days"

, "Once a week"
: "Once a week"

, "Once a month"
: "Once a month"

, "Once a year"
: "Once a year"

, "Name"
: "Name"

, "Search for users ..."
: "Search for users ..."

, "No permission"
: "No permission"

, "all"
: "all"

, "Search for groups ..."
: "Search for groups ..."

, "Valid until"
: "Valid until"

, "Send as e-mail"
: "Send as e-mail"

, "Download"
: "Download"

, "Revision"
: "Revision"

, "This folder has own revision settings"
: "This folder has own revision settings"

, "Revision active"
: "Revision active"

, "Limit revision amount to"
: "Limit revision amount to"

, "Hold-back in months"
: "Hold-back in months"

, "The grant to download files"
: "The grant to download files"

, "The grant to create anonymous download links for files"
: "The grant to create anonymous download links for files"

, "Copying data .. {0}"
: "Copying data .. {0}"

, "Moving data .. {0}"
: "Moving data .. {0}"

, "Confirm Changing of Folder Grants"
: "Confirm Changing of Folder Grants"

, "You are about to move a folder which has own grants. These grants will be lost and the folder will inherit its grants from its new parent folder."
: "You are about to move a folder which has own grants. These grants will be lost and the folder will inherit its grants from its new parent folder."

, "Please wait"
: "Please wait"

, "Error while uploading \"{fileName}\". Please try again later."
: "Error while uploading \"{fileName}\". Please try again later."

, "Download Link, Download Links"
: [
  "Download Link"
 ,"Download Links"

]
, "Grants"
: "Grants"

, "This folder has its own grants"
: "This folder has its own grants"

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: "Grants of a folder also apply recursively to all sub folders unless they have their own grants."

, "This folder is part of the data safe"
: "This folder is part of the data safe"

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."

, "Select a file"
: "Select a file"

, "Select files"
: "Select files"

, "Select a folder"
: "Select a folder"

, "Select folders"
: "Select folders"

, "Select an item"
: "Select an item"

, "Select items"
: "Select items"

, "Notifications"
: "Notifications"

, "This folder has own notification settings"
: "This folder has own notification settings"

, "Edit folder"
: "Edit folder"

, "edit file"
: "edit file"

, "File, Files"
: [
  "File"
 ,"Files"

]
, "Public Links"
: "Public Links"

, "Type"
: "Type"

, "Indexed"
: "Indexed"

, "Not yet indexed"
: "Not yet indexed"

, "Modified By"
: "Modified By"

, "Last Modified"
: "Last Modified"

, "Description"
: "Description"

, "Enter description"
: "Enter description"

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: "Sorry, Tine 2.0 would have liked to show you the contents of the file."

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: "This is possible for .doc, .jpg, .pdf and even more file formats."

, "Interested? Then let us know!"
: "Interested? Then let us know!"

, "We would be happy to make you a non-binding offer."
: "We would be happy to make you a non-binding offer."

, "This file has no contents. The Upload has failed or has not yet finished."
: "This file has no contents. The Upload has failed or has not yet finished."

, "No preview available yet - Please try again in a few minutes."
: "No preview available yet - Please try again in a few minutes."

, "Checking ..."
: "Checking ..."

, "Overwrite Existing File?"
: "Overwrite Existing File?"

, "Do you really want to overwrite the selected file?"
: "Do you really want to overwrite the selected file?"

, "Content type"
: "Content type"

, "Public Download URL"
: "Public Download URL"

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."

, "Destination has the same Path"
: "Destination has the same Path"

, "The destination has the same path as the source. No action has been performed."
: "The destination has the same path as the source. No action has been performed."

, "Destination is a Subfolder"
: "Destination is a Subfolder"

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."

, "you can't remove your own admin grant"
: "you can't remove your own admin grant"

, "My folders"
: "My folders"

, "Shared folders"
: "Shared folders"

, "Other users folders"
: "Other users folders"

, "Received"
: "Received"

, "To"
: "To"

, "Cc"
: "Cc"

, "Bcc"
: "Bcc"

, "From (E-Mail)"
: "From (E-Mail)"

, "From (Name)"
: "From (Name)"

, "Body"
: "Body"

, "Attachments"
: "Attachments"

, "Password for download required"
: "Password for download required"

, "Submit"
: "Submit"

, "File not found!"
: "File not found!"

, "manage shared folders"
: "manage shared folders"

, "Create new shared folders"
: "Create new shared folders"

, "Manage anonymous download links"
: "Manage anonymous download links"

, "Allow viewing, adding and deleting download links"
: "Allow viewing, adding and deleting download links"

, "Folder"
: "Folder"

, "Once a Day"
: "Once a Day"

, "Download Link"
: "Download Link"

, "File"
: "File"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
